@@ -77,6 +77,7 @@ class DailyPerformance(object):
     def __init__(
         self,
         returns,
+        results=None,
         pnl=None,
         net_exposures=None,
         abs_exposures=None,
@@ -113,6 +114,7 @@ class DailyPerformance(object):
                               "mean, consider removing them with the `trim_outliers` parameter".format(
                                   round(max_zscore)))
         self.pnl = pnl
+        self.results = results
         self.net_exposures = net_exposures
         self.abs_exposures = abs_exposures
         self.total_holdings = total_holdings
@@ -177,6 +179,7 @@ class DailyPerformance(object):
             compound=compound,
             rolling_sharpe_window=rolling_sharpe_window
         )
+        kwargs["results"] = results
         kwargs["returns"] = results.loc["Return"]
 
         if "Pnl" in fields:
