@@ -30,6 +30,7 @@ import scipy.stats
 
 from .utils import *
 from .base import BaseTearsheet
+from linefolio import from_moonshot
 from .perf import DailyPerformance, AggregateDailyPerformance
 
 
@@ -211,6 +212,8 @@ class Tearsheet(BaseTearsheet):
 
         self._create_constituents_tearsheet(performance)
 
+        from_moonshot(performance.results)
+
         self._save_or_show()
 
     def create_summary_tearsheet(self, performance, agg_performance=None):
@@ -330,7 +333,7 @@ class Tearsheet(BaseTearsheet):
 
         with sns.axes_style("white"):
 
-            fig = plt.figure("Performance Summary", figsize=(6, 6))
+            fig = plt.figure("Performance Summary - Linechart", figsize=(6, 6))
 
             axis = fig.add_subplot(111)
             axis.axis("off")
